import jieba, os
DIR_NAME = os.path.dirname(os.path.abspath(__file__))

jieba.load_userdict(os.path.join(DIR_NAME, 'dict.txt.big.txt'))
jieba.load_userdict(os.path.join(DIR_NAME, 'ptt.txt'))
jieba.load_userdict(os.path.join(DIR_NAME, 'wiki.dict.txt'))
jieba.load_userdict(os.path.join(DIR_NAME, 'attractions.dict.txt'))
# sougou.txt has a bad performance...
# jieba.load_userdict(os.path.join(DIR_NAME, 'sougou.txt'))


from random import shuffle
import sys
result = list(map(lambda x:x, open(sys.argv[1], 'r', encoding='utf-8')))
shuffle(result)
with open('pos.txt', 'w') as f:
        for i in result:
                f.write(i)




import jieba, json, sys, os
import jieba.posseg as pseg
stopwords = json.load(open('stopwords.json', 'r'))
jieba.load_userdict(os.path.join('dictionary', 'dict.txt.big.txt'))
jieba.load_userdict(os.path.join("dictionary", "NameDict_Ch_v2"))

def removeStopWords(sentence, rmstop=sys.argv[3]):
	def condition(x):
		x = list(x)
		word, flag = x[0], x[1]
		if len(word) > 1 and flag!='eng' and flag != 'm' and flag !='mq' and word not in stopwords:
			return True
		return False
	if rmstop == 'True':
		result = filter(condition, pseg.cut(sentence))
	else:
		result = pseg.cut(sentence)
	result = map(lambda x:list(x)[0], result)
	return list(result)

with open(sys.argv[1], 'r') as f:
	result = list(map(removeStopWords, f))

with open(sys.argv[2], 'w') as f:
	json.dump(result, f)


'''
this module supply some segmetation function for multiple language
also remove stopwords as well.
'''
import pickle
from pathlib import Path, PurePath

import nltk

STOPWORD_PKL = pickle.load(open(PurePath(Path(__file__).resolve().parent, 'stopwords.pkl'), 'rb'))
STOPWORD_EN_PKL = pickle.load(open(PurePath(Path(__file__).resolve().parent, \
'stopwords-en.pkl'), 'rb'))

nltk.download('punkt')
nltk.download('averaged_perceptron_tagger')
nltk.download('maxent_ne_chunker')
nltk.download('words')

def rmsw(doc, flag=False):
    '''
    parameter:
      flag: boolean, if true will return segment with pos.
    '''
    import udicOpenData.dictionary
    import jieba.posseg as pseg
    import jieba
    def is_chinese(keyword):
        for uchar in keyword:
            if '\u4e00' <= uchar <= '\u9fff':
                continue
            else:
                return False
        return True

    def is_english(keyword):
        if not is_chinese(keyword) and keyword.isalpha():
            return True
        return False

    doc = doc.strip()

    # flag means showing part of speech
    if flag:
        return (tuple(i) for i in pseg.cut(doc)
                if i.word not in STOPWORD_PKL
                and (is_chinese(i.word) or (is_english(i.word) and len(i.word) >= 2))
                and i.word not in ['\xa0', '\xc2']
                and not i.word.isdigit()
                )
    else:
        return (i for i in jieba.cut(doc)
                if i not in STOPWORD_PKL
                and (is_chinese(i) or (is_english(i) and len(i) >= 2))
                and i not in ['\xa0', '\xc2']
                and not i.isdigit()
                )

# Yang, 2018/07/06
def rmsw_en(doc, flag=False):
    def has_numbers(input_string):
        return any(char.isdigit() for char in input_string)

    import re
    from nltk import ne_chunk, pos_tag, word_tokenize

    chunks = ne_chunk(pos_tag(word_tokenize(doc)))
    words = [w[0] if isinstance(w, tuple) else ' '.join(t[0] for t in w) for w in chunks]
    for word in words:
        word = re.sub(r'[^a-zA-Z0-9 -]', '', word)
        if word and not has_numbers(word) and word.lower() not in STOPWORD_EN_PKL:
            yield word



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
import os, json, pkg_resources, sys
__name__ = 'udicOpenData'
mode = sys.argv[1]
dictionary_filename_extension = 'dic' if mode == 'ik' else 'dict'
stopword_filename_extension = 'dic' if mode == 'ik' else 'txt'

# -2 is index of array, means doesn't need weight
# -1 means containing weight
dictionary_pattern = -2 if mode == 'ik' else -1
filepath = pkg_resources.resource_filename(__name__, 'dictionary')

# output dictionary for elasticsearch
with open('mydict.{}'.format(dictionary_filename_extension), 'w', encoding='utf-8') as outputFile:
	for dictfile in os.listdir(pkg_resources.resource_filename(__name__, 'dictionary')):
		if '.txt' in dictfile:
			with open(os.path.join(filepath, dictfile), 'r', encoding='utf-8') as f:
				print(dictfile)
				new_dictionary = [' '.join('_'.join(keyword.split()[:dictionary_pattern]).rsplit('_', 1))+'\n' for keyword in f]

			# output to output file
			for keyword in new_dictionary:
				outputFile.write(keyword)

# output stopword for elasticsearch
with open('ext_stopword.{}'.format(stopword_filename_extension), 'w') as f:
	for i in ' \n'.join(json.load(open(pkg_resources.resource_filename(__name__, 'stopwords/stopwords.json'), 'r'))):
		f.write(i)


from distutils.core import setup

setup(
    name = 'udicOpenData',
    packages=['udicOpenData'],
    package_dir={'udicOpenData':'udicOpenData'},
    package_data={'udicOpenData':['dictionary/*', 'stopwords/*', 'scripts/dump2es.py']},
    version = '1.9',
    description = 'udic dictionary, stopwords module',
    author = ['davidtnfsh', 'CYJiang0718'],
    author_email = 'davidtnfsh@gmail.com',
    url = 'https://github.com/UDICatNCHU/Open-Training-Data',
    download_url = '',
    keywords = ['udicOpenData', 'jieba', 'dictionary', 'stopwords'],
    classifiers = [],
    license='GPL3.0',
    install_requires=[
        'jieba',
        'nltk',
        'numpy'
    ],
    zip_safe=True,
    scripts=['udicOpenData/scripts/dump2es.py']
)
